# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class OIDCAuthConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auth_enabled': 'bool',
        'client_id': 'str',
        'issuer': 'str',
        'logout_url': 'str',
        'scopes': 'list[OIDCProxyScope]',
        'path_config': 'OIDCAuthPathConfig'
    }

    attribute_map = {
        'auth_enabled': 'auth_enabled',
        'client_id': 'client_id',
        'issuer': 'issuer',
        'logout_url': 'logout_url',
        'scopes': 'scopes',
        'path_config': 'path_config'
    }

    def __init__(self, auth_enabled=None, client_id=None, issuer=None, logout_url=None, scopes=None, path_config=None, local_vars_configuration=None):  # noqa: E501
        """OIDCAuthConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._auth_enabled = None
        self._client_id = None
        self._issuer = None
        self._logout_url = None
        self._scopes = None
        self._path_config = None
        self.discriminator = None

        self.auth_enabled = auth_enabled
        self.client_id = client_id
        self.issuer = issuer
        if logout_url is not None:
            self.logout_url = logout_url
        if scopes is not None:
            self.scopes = scopes
        if path_config is not None:
            self.path_config = path_config

    @property
    def auth_enabled(self):
        """Gets the auth_enabled of this OIDCAuthConfig.  # noqa: E501

        Whether the authentication is enabled. If true, users will be forced to log in before accessing any of its assets. If false, no authentication will be performed.   # noqa: E501

        :return: The auth_enabled of this OIDCAuthConfig.  # noqa: E501
        :rtype: bool
        """
        return self._auth_enabled

    @auth_enabled.setter
    def auth_enabled(self, auth_enabled):
        """Sets the auth_enabled of this OIDCAuthConfig.

        Whether the authentication is enabled. If true, users will be forced to log in before accessing any of its assets. If false, no authentication will be performed.   # noqa: E501

        :param auth_enabled: The auth_enabled of this OIDCAuthConfig.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and auth_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_enabled`, must not be `None`")  # noqa: E501

        self._auth_enabled = auth_enabled

    @property
    def client_id(self):
        """Gets the client_id of this OIDCAuthConfig.  # noqa: E501

        The OIDC client identifier to use when logging in with this application.  # noqa: E501

        :return: The client_id of this OIDCAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this OIDCAuthConfig.

        The OIDC client identifier to use when logging in with this application.  # noqa: E501

        :param client_id: The client_id of this OIDCAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def issuer(self):
        """Gets the issuer of this OIDCAuthConfig.  # noqa: E501

        The url of the OpenID Connect issuer.  # noqa: E501

        :return: The issuer of this OIDCAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this OIDCAuthConfig.

        The url of the OpenID Connect issuer.  # noqa: E501

        :param issuer: The issuer of this OIDCAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer`, must not be `None`")  # noqa: E501

        self._issuer = issuer

    @property
    def logout_url(self):
        """Gets the logout_url of this OIDCAuthConfig.  # noqa: E501

        The relative http path to the logout page.  # noqa: E501

        :return: The logout_url of this OIDCAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._logout_url

    @logout_url.setter
    def logout_url(self, logout_url):
        """Sets the logout_url of this OIDCAuthConfig.

        The relative http path to the logout page.  # noqa: E501

        :param logout_url: The logout_url of this OIDCAuthConfig.  # noqa: E501
        :type: str
        """

        self._logout_url = logout_url

    @property
    def scopes(self):
        """Gets the scopes of this OIDCAuthConfig.  # noqa: E501

        A list of scopes to be requested on behalf of the user of the application.  # noqa: E501

        :return: The scopes of this OIDCAuthConfig.  # noqa: E501
        :rtype: list[OIDCProxyScope]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this OIDCAuthConfig.

        A list of scopes to be requested on behalf of the user of the application.  # noqa: E501

        :param scopes: The scopes of this OIDCAuthConfig.  # noqa: E501
        :type: list[OIDCProxyScope]
        """

        self._scopes = scopes

    @property
    def path_config(self):
        """Gets the path_config of this OIDCAuthConfig.  # noqa: E501


        :return: The path_config of this OIDCAuthConfig.  # noqa: E501
        :rtype: OIDCAuthPathConfig
        """
        return self._path_config

    @path_config.setter
    def path_config(self, path_config):
        """Sets the path_config of this OIDCAuthConfig.


        :param path_config: The path_config of this OIDCAuthConfig.  # noqa: E501
        :type: OIDCAuthPathConfig
        """

        self._path_config = path_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OIDCAuthConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OIDCAuthConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class RuntimeStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'overall_status': 'str',
        'running_replicas': 'int',
        'error_message': 'str',
        'restarts': 'int',
        'cpu': 'float',
        'memory': 'float',
        'last_apply_time': 'datetime',
        'updated': 'datetime',
        'running_image': 'str',
        'running_hash': 'str',
        'org_id': 'str'
    }

    attribute_map = {
        'overall_status': 'overall_status',
        'running_replicas': 'running_replicas',
        'error_message': 'error_message',
        'restarts': 'restarts',
        'cpu': 'cpu',
        'memory': 'memory',
        'last_apply_time': 'last_apply_time',
        'updated': 'updated',
        'running_image': 'running_image',
        'running_hash': 'running_hash',
        'org_id': 'org_id'
    }

    def __init__(self, overall_status=None, running_replicas=None, error_message=None, restarts=None, cpu=None, memory=None, last_apply_time=None, updated=None, running_image=None, running_hash=None, org_id=None, local_vars_configuration=None):  # noqa: E501
        """RuntimeStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._overall_status = None
        self._running_replicas = None
        self._error_message = None
        self._restarts = None
        self._cpu = None
        self._memory = None
        self._last_apply_time = None
        self._updated = None
        self._running_image = None
        self._running_hash = None
        self._org_id = None
        self.discriminator = None

        if overall_status is not None:
            self.overall_status = overall_status
        if running_replicas is not None:
            self.running_replicas = running_replicas
        if error_message is not None:
            self.error_message = error_message
        if restarts is not None:
            self.restarts = restarts
        if cpu is not None:
            self.cpu = cpu
        if memory is not None:
            self.memory = memory
        if last_apply_time is not None:
            self.last_apply_time = last_apply_time
        if updated is not None:
            self.updated = updated
        if running_image is not None:
            self.running_image = running_image
        if running_hash is not None:
            self.running_hash = running_hash
        if org_id is not None:
            self.org_id = org_id

    @property
    def overall_status(self):
        """Gets the overall_status of this RuntimeStatus.  # noqa: E501

        The status of the running components. - A `good` status means that no action is neccessary on this environment - A `warn` status means that there is an issue that should be dealt with   Examples include a rollout failing or crashing containers - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could   mean that there were multiple failed rollouts, containers are unstable,   access to a neccessary service is down or other problems. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   an issue with the platform   # noqa: E501

        :return: The overall_status of this RuntimeStatus.  # noqa: E501
        :rtype: str
        """
        return self._overall_status

    @overall_status.setter
    def overall_status(self, overall_status):
        """Sets the overall_status of this RuntimeStatus.

        The status of the running components. - A `good` status means that no action is neccessary on this environment - A `warn` status means that there is an issue that should be dealt with   Examples include a rollout failing or crashing containers - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could   mean that there were multiple failed rollouts, containers are unstable,   access to a neccessary service is down or other problems. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   an issue with the platform   # noqa: E501

        :param overall_status: The overall_status of this RuntimeStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["good", "warn", "down", "stale"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and overall_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `overall_status` ({0}), must be one of {1}"  # noqa: E501
                .format(overall_status, allowed_values)
            )

        self._overall_status = overall_status

    @property
    def running_replicas(self):
        """Gets the running_replicas of this RuntimeStatus.  # noqa: E501

        The number of current running replicas. 2 is redundant, 1 could indicate error handling, 0 is down.   # noqa: E501

        :return: The running_replicas of this RuntimeStatus.  # noqa: E501
        :rtype: int
        """
        return self._running_replicas

    @running_replicas.setter
    def running_replicas(self, running_replicas):
        """Sets the running_replicas of this RuntimeStatus.

        The number of current running replicas. 2 is redundant, 1 could indicate error handling, 0 is down.   # noqa: E501

        :param running_replicas: The running_replicas of this RuntimeStatus.  # noqa: E501
        :type: int
        """

        self._running_replicas = running_replicas

    @property
    def error_message(self):
        """Gets the error_message of this RuntimeStatus.  # noqa: E501

        The error in running the current instance. Common errors include CrashLoopBackoff, ContainerPullError, ConfigError. If there is no error description, this will be empty.   # noqa: E501

        :return: The error_message of this RuntimeStatus.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this RuntimeStatus.

        The error in running the current instance. Common errors include CrashLoopBackoff, ContainerPullError, ConfigError. If there is no error description, this will be empty.   # noqa: E501

        :param error_message: The error_message of this RuntimeStatus.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def restarts(self):
        """Gets the restarts of this RuntimeStatus.  # noqa: E501

        How many times a container has restarted across all replicas of this instance. A non-zero number might indicate some intermittent error that is handled by the Agilicus system. A large number of errors could indicate problems in the application   # noqa: E501

        :return: The restarts of this RuntimeStatus.  # noqa: E501
        :rtype: int
        """
        return self._restarts

    @restarts.setter
    def restarts(self, restarts):
        """Sets the restarts of this RuntimeStatus.

        How many times a container has restarted across all replicas of this instance. A non-zero number might indicate some intermittent error that is handled by the Agilicus system. A large number of errors could indicate problems in the application   # noqa: E501

        :param restarts: The restarts of this RuntimeStatus.  # noqa: E501
        :type: int
        """

        self._restarts = restarts

    @property
    def cpu(self):
        """Gets the cpu of this RuntimeStatus.  # noqa: E501

        The current number of CPU cores used by all the containers for the instance. A high number eg 1.00 may indicate performance problems as a container is unable to service all requests   # noqa: E501

        :return: The cpu of this RuntimeStatus.  # noqa: E501
        :rtype: float
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """Sets the cpu of this RuntimeStatus.

        The current number of CPU cores used by all the containers for the instance. A high number eg 1.00 may indicate performance problems as a container is unable to service all requests   # noqa: E501

        :param cpu: The cpu of this RuntimeStatus.  # noqa: E501
        :type: float
        """

        self._cpu = cpu

    @property
    def memory(self):
        """Gets the memory of this RuntimeStatus.  # noqa: E501

        The amount of RAM used by all containers used for the instance in MiB   # noqa: E501

        :return: The memory of this RuntimeStatus.  # noqa: E501
        :rtype: float
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this RuntimeStatus.

        The amount of RAM used by all containers used for the instance in MiB   # noqa: E501

        :param memory: The memory of this RuntimeStatus.  # noqa: E501
        :type: float
        """

        self._memory = memory

    @property
    def last_apply_time(self):
        """Gets the last_apply_time of this RuntimeStatus.  # noqa: E501

        The last time any change was applied to the running containers. This can be used to indicate if the system has 'picked up' a recent change that was made   # noqa: E501

        :return: The last_apply_time of this RuntimeStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_apply_time

    @last_apply_time.setter
    def last_apply_time(self, last_apply_time):
        """Sets the last_apply_time of this RuntimeStatus.

        The last time any change was applied to the running containers. This can be used to indicate if the system has 'picked up' a recent change that was made   # noqa: E501

        :param last_apply_time: The last_apply_time of this RuntimeStatus.  # noqa: E501
        :type: datetime
        """

        self._last_apply_time = last_apply_time

    @property
    def updated(self):
        """Gets the updated of this RuntimeStatus.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this RuntimeStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this RuntimeStatus.

        Update time  # noqa: E501

        :param updated: The updated of this RuntimeStatus.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    @property
    def running_image(self):
        """Gets the running_image of this RuntimeStatus.  # noqa: E501

        The container tag identifies what container is currently running in this instance. This could be different than the configured image if there was an error upgrading. Although relatively rare in practice, the same image tag could have been pushed with many different images, when the container is started it will pull the latest version. See running_hash for more information   # noqa: E501

        :return: The running_image of this RuntimeStatus.  # noqa: E501
        :rtype: str
        """
        return self._running_image

    @running_image.setter
    def running_image(self, running_image):
        """Sets the running_image of this RuntimeStatus.

        The container tag identifies what container is currently running in this instance. This could be different than the configured image if there was an error upgrading. Although relatively rare in practice, the same image tag could have been pushed with many different images, when the container is started it will pull the latest version. See running_hash for more information   # noqa: E501

        :param running_image: The running_image of this RuntimeStatus.  # noqa: E501
        :type: str
        """

        self._running_image = running_image

    @property
    def running_hash(self):
        """Gets the running_hash of this RuntimeStatus.  # noqa: E501

        The container hash of What versions users see when they browse to the site. If a image tag has been pushed multiple times, ie for hotfixes then this could be used to identify exactly what software is running   # noqa: E501

        :return: The running_hash of this RuntimeStatus.  # noqa: E501
        :rtype: str
        """
        return self._running_hash

    @running_hash.setter
    def running_hash(self, running_hash):
        """Sets the running_hash of this RuntimeStatus.

        The container hash of What versions users see when they browse to the site. If a image tag has been pushed multiple times, ie for hotfixes then this could be used to identify exactly what software is running   # noqa: E501

        :param running_hash: The running_hash of this RuntimeStatus.  # noqa: E501
        :type: str
        """

        self._running_hash = running_hash

    @property
    def org_id(self):
        """Gets the org_id of this RuntimeStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this RuntimeStatus.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this RuntimeStatus.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this RuntimeStatus.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuntimeStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RuntimeStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.challenges_api import ChallengesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestChallengesApi(unittest.TestCase):
    """ChallengesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.challenges_api.ChallengesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_challenge(self):
        """Test case for create_challenge

        create a challenge  # noqa: E501
        """
        pass

    def test_create_totp_enrollment(self):
        """Test case for create_totp_enrollment

        create a TOTP challenge enrollment  # noqa: E501
        """
        pass

    def test_create_webauthn_enrollment(self):
        """Test case for create_webauthn_enrollment

        create a WebAuthN challenge enrollment  # noqa: E501
        """
        pass

    def test_delete_challenge(self):
        """Test case for delete_challenge

        Delete the challenge specified by challenge_id  # noqa: E501
        """
        pass

    def test_delete_totp_enrollment(self):
        """Test case for delete_totp_enrollment

        Delete the TOTP enrollment specified by totp id  # noqa: E501
        """
        pass

    def test_delete_webauthn_enrollment(self):
        """Test case for delete_webauthn_enrollment

        Delete the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        """
        pass

    def test_get_answer(self):
        """Test case for get_answer

        answer a challenge  # noqa: E501
        """
        pass

    def test_get_challenge(self):
        """Test case for get_challenge

        Get the challenge specified by challenge_id  # noqa: E501
        """
        pass

    def test_get_totp_enrollment(self):
        """Test case for get_totp_enrollment

        Get the TOTP enrollment specified by totp_id  # noqa: E501
        """
        pass

    def test_get_webauthn_enrollment(self):
        """Test case for get_webauthn_enrollment

        Get the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        """
        pass

    def test_list_totp_enrollment(self):
        """Test case for list_totp_enrollment

        List the totp enrollment results  # noqa: E501
        """
        pass

    def test_list_webauthn_enrollments(self):
        """Test case for list_webauthn_enrollments

        List the webauthn enrollments  # noqa: E501
        """
        pass

    def test_replace_challenge(self):
        """Test case for replace_challenge

        Replace the challenge specified by challenge_id  # noqa: E501
        """
        pass

    def test_update_totp_enrollment(self):
        """Test case for update_totp_enrollment

        Update the totp_enrollment if the answer provided is correct.  # noqa: E501
        """
        pass

    def test_update_webauthn_enrollment(self):
        """Test case for update_webauthn_enrollment

        Update the WebAuthN enrollment if the answer provided is correct.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class FilesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_file(self, name, file_zip, **kwargs):  # noqa: E501
        """upload a file  # noqa: E501

        Upload a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_file(name, file_zip, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Name of file (required)
        :param file file_zip: The contents of the file in binary format (required)
        :param str org_id: Unique identifier
        :param str tag: A file tag
        :param str label: A file label
        :param StorageRegion region:
        :param FileVisibility visibility:
        :param str md5_hash: MD5 Hash of file in base64
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_file_with_http_info(name, file_zip, **kwargs)  # noqa: E501

    def add_file_with_http_info(self, name, file_zip, **kwargs):  # noqa: E501
        """upload a file  # noqa: E501

        Upload a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_file_with_http_info(name, file_zip, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Name of file (required)
        :param file file_zip: The contents of the file in binary format (required)
        :param str org_id: Unique identifier
        :param str tag: A file tag
        :param str label: A file label
        :param StorageRegion region:
        :param FileVisibility visibility:
        :param str md5_hash: MD5 Hash of file in base64
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileSummary, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['name', 'file_zip', 'org_id', 'tag', 'label', 'region', 'visibility', 'md5_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `add_file`")  # noqa: E501
        # verify the required parameter 'file_zip' is set
        if self.api_client.client_side_validation and ('file_zip' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_zip'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_zip` when calling `add_file`")  # noqa: E501

        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `add_file`, length must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `name` when calling `add_file`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'org_id' in local_var_params:
            form_params.append(('org_id', local_var_params['org_id']))  # noqa: E501
        if 'tag' in local_var_params:
            form_params.append(('tag', local_var_params['tag']))  # noqa: E501
        if 'label' in local_var_params:
            form_params.append(('label', local_var_params['label']))  # noqa: E501
        if 'region' in local_var_params:
            form_params.append(('region', local_var_params['region']))  # noqa: E501
        if 'name' in local_var_params:
            form_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'visibility' in local_var_params:
            form_params.append(('visibility', local_var_params['visibility']))  # noqa: E501
        if 'md5_hash' in local_var_params:
            form_params.append(('md5_hash', local_var_params['md5_hash']))  # noqa: E501
        if 'file_zip' in local_var_params:
            local_var_files['file_zip'] = local_var_params['file_zip']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """Delete a File  # noqa: E501

        Delete a File  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def delete_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Delete a File  # noqa: E501

        Delete a File  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['file_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `delete_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['file_id'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{file_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_download(self, file_id, **kwargs):  # noqa: E501
        """Download File  # noqa: E501

        Download File  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_download(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_download_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_download_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Download File  # noqa: E501

        Download File  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_download_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['file_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_download" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_download`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['file_id'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files_download/{file_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file(self, file_id, **kwargs):  # noqa: E501
        """Get File metadata  # noqa: E501

        Get File metadata  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Get File metadata  # noqa: E501

        Get File metadata  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileSummary, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['file_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['file_id'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{file_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_files(self, **kwargs):  # noqa: E501
        """Query Files  # noqa: E501

        Query Files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str org_id: Organisation Unique identifier
        :param str user_id: Query based on user id
        :param str tag: Search files based on tag
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListFilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_files_with_http_info(**kwargs)  # noqa: E501

    def list_files_with_http_info(self, **kwargs):  # noqa: E501
        """Query Files  # noqa: E501

        Query Files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str org_id: Organisation Unique identifier
        :param str user_id: Query based on user id
        :param str tag: Search files based on tag
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListFilesResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'org_id', 'user_id', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_files" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_files`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_files`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501
        if 'tag' in local_var_params and local_var_params['tag'] is not None:  # noqa: E501
            query_params.append(('tag', local_var_params['tag']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListFilesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_file(self, file_id, file, **kwargs):  # noqa: E501
        """Update a file  # noqa: E501

        Update a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_file(file_id, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param File file: Upload file request (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_file_with_http_info(file_id, file, **kwargs)  # noqa: E501

    def replace_file_with_http_info(self, file_id, file, **kwargs):  # noqa: E501
        """Update a file  # noqa: E501

        Update a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_file_with_http_info(file_id, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: file_id path (required)
        :param File file: Upload file request (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileSummary, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['file_id', 'file', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `replace_file`")  # noqa: E501
        # verify the required parameter 'file' is set
        if self.api_client.client_side_validation and ('file' not in local_var_params or  # noqa: E501
                                                        local_var_params['file'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file` when calling `replace_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['file_id'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'file' in local_var_params:
            body_params = local_var_params['file']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{file_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_user_request_info_response import ListUserRequestInfoResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListUserRequestInfoResponse(unittest.TestCase):
    """ListUserRequestInfoResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListUserRequestInfoResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_user_request_info_response.ListUserRequestInfoResponse()  # noqa: E501
        if include_optional :
            return ListUserRequestInfoResponse(
                user_requests = [
                    agilicus_api.models.user_request_info.UserRequestInfo(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                            user_id = 'tuU7smH86zAXMl76sua6xQ', 
                            org_id = 'IAsl3dl40aSsfLKiU76', 
                            requested_resource = 'phone', 
                            requested_sub_resource = 'self', 
                            requested_resource_type = 'application_access', 
                            request_information = 'I need this to do my job', 
                            state = 'pending', ), 
                        status = agilicus_api.models.user_request_info_status.UserRequestInfoStatus(
                            email = 'foo@example.com', ), )
                    ], 
                limit = 56
            )
        else :
            return ListUserRequestInfoResponse(
                user_requests = [
                    agilicus_api.models.user_request_info.UserRequestInfo(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.user_request_info_spec.UserRequestInfoSpec(
                            user_id = 'tuU7smH86zAXMl76sua6xQ', 
                            org_id = 'IAsl3dl40aSsfLKiU76', 
                            requested_resource = 'phone', 
                            requested_sub_resource = 'self', 
                            requested_resource_type = 'application_access', 
                            request_information = 'I need this to do my job', 
                            state = 'pending', ), 
                        status = agilicus_api.models.user_request_info_status.UserRequestInfoStatus(
                            email = 'foo@example.com', ), )
                    ],
                limit = 56,
        )

    def testListUserRequestInfoResponse(self):
        """Test ListUserRequestInfoResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class APIKeyStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_key': 'str',
        'token_id': 'str'
    }

    attribute_map = {
        'api_key': 'api_key',
        'token_id': 'token_id'
    }

    def __init__(self, api_key=None, token_id=None, local_vars_configuration=None):  # noqa: E501
        """APIKeyStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_key = None
        self._token_id = None
        self.discriminator = None

        if api_key is not None:
            self.api_key = api_key
        self.token_id = token_id

    @property
    def api_key(self):
        """Gets the api_key of this APIKeyStatus.  # noqa: E501

        The value to use as the password in the basic authentication flow. Note that this value will only be present in the APIKeyStatus when creating the API Key. It is omitted in future requests to prevent it from leaking. Treat this key like any other password: keep it secret; keep it safe.   # noqa: E501

        :return: The api_key of this APIKeyStatus.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this APIKeyStatus.

        The value to use as the password in the basic authentication flow. Note that this value will only be present in the APIKeyStatus when creating the API Key. It is omitted in future requests to prevent it from leaking. Treat this key like any other password: keep it secret; keep it safe.   # noqa: E501

        :param api_key: The api_key of this APIKeyStatus.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def token_id(self):
        """Gets the token_id of this APIKeyStatus.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The token_id of this APIKeyStatus.  # noqa: E501
        :rtype: str
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this APIKeyStatus.

        Unique identifier  # noqa: E501

        :param token_id: The token_id of this APIKeyStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and token_id is None:  # noqa: E501
            raise ValueError("Invalid value for `token_id`, must not be `None`")  # noqa: E501

        self._token_id = token_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIKeyStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIKeyStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_application_summary_response import ListApplicationSummaryResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListApplicationSummaryResponse(unittest.TestCase):
    """ListApplicationSummaryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListApplicationSummaryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_application_summary_response.ListApplicationSummaryResponse()  # noqa: E501
        if include_optional :
            return ListApplicationSummaryResponse(
                application_summaries = [
                    agilicus_api.models.application_summary.ApplicationSummary(
                        status = agilicus_api.models.application_summary_status.ApplicationSummaryStatus(
                            application_id = '39dl4dDJGdjgud8', 
                            application_name = 'parking', 
                            assigned_org_id = 'as9f9adfDFwEE9', 
                            published = 'no', 
                            description = 'An application to submit parking requests', 
                            category = 'citizen-facing', 
                            icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                            default_role_name = 'self', 
                            default_role_id = 'as0Z6fXFsl23', ), )
                    ], 
                limit = 56
            )
        else :
            return ListApplicationSummaryResponse(
                application_summaries = [
                    agilicus_api.models.application_summary.ApplicationSummary(
                        status = agilicus_api.models.application_summary_status.ApplicationSummaryStatus(
                            application_id = '39dl4dDJGdjgud8', 
                            application_name = 'parking', 
                            assigned_org_id = 'as9f9adfDFwEE9', 
                            published = 'no', 
                            description = 'An application to submit parking requests', 
                            category = 'citizen-facing', 
                            icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                            default_role_name = 'self', 
                            default_role_id = 'as0Z6fXFsl23', ), )
                    ],
                limit = 56,
        )

    def testListApplicationSummaryResponse(self):
        """Test ListApplicationSummaryResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class OIDCUpstreamIdentityProvider(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'icon': 'str',
        'issuer': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'issuer_external_host': 'str',
        'username_key': 'str',
        'email_key': 'str',
        'email_verification_required': 'bool',
        'request_user_info': 'bool',
        'user_id_key': 'str',
        'auto_create_status': 'AutoCreateStatus'
    }

    attribute_map = {
        'name': 'name',
        'icon': 'icon',
        'issuer': 'issuer',
        'client_id': 'client_id',
        'client_secret': 'client_secret',
        'issuer_external_host': 'issuer_external_host',
        'username_key': 'username_key',
        'email_key': 'email_key',
        'email_verification_required': 'email_verification_required',
        'request_user_info': 'request_user_info',
        'user_id_key': 'user_id_key',
        'auto_create_status': 'auto_create_status'
    }

    def __init__(self, name=None, icon=None, issuer=None, client_id=None, client_secret=None, issuer_external_host=None, username_key=None, email_key=None, email_verification_required=True, request_user_info=None, user_id_key=None, auto_create_status=None, local_vars_configuration=None):  # noqa: E501
        """OIDCUpstreamIdentityProvider - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._icon = None
        self._issuer = None
        self._client_id = None
        self._client_secret = None
        self._issuer_external_host = None
        self._username_key = None
        self._email_key = None
        self._email_verification_required = None
        self._request_user_info = None
        self._user_id_key = None
        self._auto_create_status = None
        self.discriminator = None

        self.name = name
        if icon is not None:
            self.icon = icon
        self.issuer = issuer
        self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if issuer_external_host is not None:
            self.issuer_external_host = issuer_external_host
        if username_key is not None:
            self.username_key = username_key
        if email_key is not None:
            self.email_key = email_key
        if email_verification_required is not None:
            self.email_verification_required = email_verification_required
        if request_user_info is not None:
            self.request_user_info = request_user_info
        if user_id_key is not None:
            self.user_id_key = user_id_key
        if auto_create_status is not None:
            self.auto_create_status = auto_create_status

    @property
    def name(self):
        """Gets the name of this OIDCUpstreamIdentityProvider.  # noqa: E501

        A name used to uniquely refer to the upstream identity provider configuration. This is the text that will be displayed when presenting the upstream identity for login.  # noqa: E501

        :return: The name of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OIDCUpstreamIdentityProvider.

        A name used to uniquely refer to the upstream identity provider configuration. This is the text that will be displayed when presenting the upstream identity for login.  # noqa: E501

        :param name: The name of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def icon(self):
        """Gets the icon of this OIDCUpstreamIdentityProvider.  # noqa: E501

        The icon file to be used, limited to: numbers, letters, underscores, hyphens and periods. It is part of a css class (with the periods replaced by underscores).  To use a custom icon than the provided default you will need to add the icon the static/img folder and update the static css file to add a new css button like below ```json .dex-btn-icon--<your-logo_svg> {   background-image: url(../static/img/<your-logo.svg>); } ```  To use a default icon simply enter an icon name from the pre-provided defaults found in the static/img folder The default icons are   - bitbucket   - coreos   - email   - github   - gitlab   - google   - ldap   - linkedin   - microsoft   - oidc   - saml   # noqa: E501

        :return: The icon of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this OIDCUpstreamIdentityProvider.

        The icon file to be used, limited to: numbers, letters, underscores, hyphens and periods. It is part of a css class (with the periods replaced by underscores).  To use a custom icon than the provided default you will need to add the icon the static/img folder and update the static css file to add a new css button like below ```json .dex-btn-icon--<your-logo_svg> {   background-image: url(../static/img/<your-logo.svg>); } ```  To use a default icon simply enter an icon name from the pre-provided defaults found in the static/img folder The default icons are   - bitbucket   - coreos   - email   - github   - gitlab   - google   - ldap   - linkedin   - microsoft   - oidc   - saml   # noqa: E501

        :param icon: The icon of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and len(icon) > 50):
            raise ValueError("Invalid value for `icon`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and len(icon) < 1):
            raise ValueError("Invalid value for `icon`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and not re.search(r'^[0-9a-zA-Z-_.]+$', icon)):  # noqa: E501
            raise ValueError(r"Invalid value for `icon`, must be a follow pattern or equal to `/^[0-9a-zA-Z-_.]+$/`")  # noqa: E501

        self._icon = icon

    @property
    def issuer(self):
        """Gets the issuer of this OIDCUpstreamIdentityProvider.  # noqa: E501

        The upstream issuer uri. This is the URI which identifies the issuer against which users selecting this OIDCUpstreamIdentityProvider will authenticate. The issuer must support the OpenID Connect discovery document described here: https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderConfig.  # noqa: E501

        :return: The issuer of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this OIDCUpstreamIdentityProvider.

        The upstream issuer uri. This is the URI which identifies the issuer against which users selecting this OIDCUpstreamIdentityProvider will authenticate. The issuer must support the OpenID Connect discovery document described here: https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderConfig.  # noqa: E501

        :param issuer: The issuer of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) > 511):
            raise ValueError("Invalid value for `issuer`, length must be less than or equal to `511`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) < 1):
            raise ValueError("Invalid value for `issuer`, length must be greater than or equal to `1`")  # noqa: E501

        self._issuer = issuer

    @property
    def client_id(self):
        """Gets the client_id of this OIDCUpstreamIdentityProvider.  # noqa: E501

        The client ID for the upstream identity provider  # noqa: E501

        :return: The client_id of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this OIDCUpstreamIdentityProvider.

        The client ID for the upstream identity provider  # noqa: E501

        :param client_id: The client_id of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_id is not None and len(client_id) > 100):
            raise ValueError("Invalid value for `client_id`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_id is not None and len(client_id) < 1):
            raise ValueError("Invalid value for `client_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this OIDCUpstreamIdentityProvider.  # noqa: E501

        The secret presented to the upstream during any workflows which require authentication  # noqa: E501

        :return: The client_secret of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this OIDCUpstreamIdentityProvider.

        The secret presented to the upstream during any workflows which require authentication  # noqa: E501

        :param client_secret: The client_secret of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client_secret is not None and len(client_secret) > 255):
            raise ValueError("Invalid value for `client_secret`, length must be less than or equal to `255`")  # noqa: E501

        self._client_secret = client_secret

    @property
    def issuer_external_host(self):
        """Gets the issuer_external_host of this OIDCUpstreamIdentityProvider.  # noqa: E501

        A proxy standing in for the main issuer host. Use this if fronting the upstream through the Agilicus infrastructure  # noqa: E501

        :return: The issuer_external_host of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._issuer_external_host

    @issuer_external_host.setter
    def issuer_external_host(self, issuer_external_host):
        """Sets the issuer_external_host of this OIDCUpstreamIdentityProvider.

        A proxy standing in for the main issuer host. Use this if fronting the upstream through the Agilicus infrastructure  # noqa: E501

        :param issuer_external_host: The issuer_external_host of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                issuer_external_host is not None and len(issuer_external_host) > 255):
            raise ValueError("Invalid value for `issuer_external_host`, length must be less than or equal to `255`")  # noqa: E501

        self._issuer_external_host = issuer_external_host

    @property
    def username_key(self):
        """Gets the username_key of this OIDCUpstreamIdentityProvider.  # noqa: E501

        Allows changing the key in the OIDC response claims used to determine the full name of the user. If not present, defaults to the standard name  # noqa: E501

        :return: The username_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._username_key

    @username_key.setter
    def username_key(self, username_key):
        """Sets the username_key of this OIDCUpstreamIdentityProvider.

        Allows changing the key in the OIDC response claims used to determine the full name of the user. If not present, defaults to the standard name  # noqa: E501

        :param username_key: The username_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                username_key is not None and len(username_key) > 255):
            raise ValueError("Invalid value for `username_key`, length must be less than or equal to `255`")  # noqa: E501

        self._username_key = username_key

    @property
    def email_key(self):
        """Gets the email_key of this OIDCUpstreamIdentityProvider.  # noqa: E501

        Allows changing the key in the OIDC response claims used to determine the email address of the user. If not present, defaults to the standard email  # noqa: E501

        :return: The email_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._email_key

    @email_key.setter
    def email_key(self, email_key):
        """Sets the email_key of this OIDCUpstreamIdentityProvider.

        Allows changing the key in the OIDC response claims used to determine the email address of the user. If not present, defaults to the standard email  # noqa: E501

        :param email_key: The email_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email_key is not None and len(email_key) > 255):
            raise ValueError("Invalid value for `email_key`, length must be less than or equal to `255`")  # noqa: E501

        self._email_key = email_key

    @property
    def email_verification_required(self):
        """Gets the email_verification_required of this OIDCUpstreamIdentityProvider.  # noqa: E501

        Controls whether email verification is required for this OIDC provider. Some OIDC providers do not take steps to verify the email address of users, or may not do so in all cases. Setting this value to true will reject any successful upstream logins for users which have not had their email address verified.  # noqa: E501

        :return: The email_verification_required of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: bool
        """
        return self._email_verification_required

    @email_verification_required.setter
    def email_verification_required(self, email_verification_required):
        """Sets the email_verification_required of this OIDCUpstreamIdentityProvider.

        Controls whether email verification is required for this OIDC provider. Some OIDC providers do not take steps to verify the email address of users, or may not do so in all cases. Setting this value to true will reject any successful upstream logins for users which have not had their email address verified.  # noqa: E501

        :param email_verification_required: The email_verification_required of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: bool
        """

        self._email_verification_required = email_verification_required

    @property
    def request_user_info(self):
        """Gets the request_user_info of this OIDCUpstreamIdentityProvider.  # noqa: E501

        Controls whether the system will retrieve extra information about the user from the provider's user_info endpoint. This can be useful if the initial OIDC response does not contain sufficient information to determine the email address or user's name. Setting this value to true will cause extra requests to be generated to the upstream every time a user logs in to it.  # noqa: E501

        :return: The request_user_info of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: bool
        """
        return self._request_user_info

    @request_user_info.setter
    def request_user_info(self, request_user_info):
        """Sets the request_user_info of this OIDCUpstreamIdentityProvider.

        Controls whether the system will retrieve extra information about the user from the provider's user_info endpoint. This can be useful if the initial OIDC response does not contain sufficient information to determine the email address or user's name. Setting this value to true will cause extra requests to be generated to the upstream every time a user logs in to it.  # noqa: E501

        :param request_user_info: The request_user_info of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: bool
        """

        self._request_user_info = request_user_info

    @property
    def user_id_key(self):
        """Gets the user_id_key of this OIDCUpstreamIdentityProvider.  # noqa: E501

        Changes the key used to determine the id of the user in this upstream. The key will be used to retrieve the user id from the id token claims returned from the upstream when the user logs in. This user id is in turn used to link the user to its identity within the system. If not present, the system will fall back on the default, which is `sub`.   # noqa: E501

        :return: The user_id_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: str
        """
        return self._user_id_key

    @user_id_key.setter
    def user_id_key(self, user_id_key):
        """Sets the user_id_key of this OIDCUpstreamIdentityProvider.

        Changes the key used to determine the id of the user in this upstream. The key will be used to retrieve the user id from the id token claims returned from the upstream when the user logs in. This user id is in turn used to link the user to its identity within the system. If not present, the system will fall back on the default, which is `sub`.   # noqa: E501

        :param user_id_key: The user_id_key of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                user_id_key is not None and len(user_id_key) > 255):
            raise ValueError("Invalid value for `user_id_key`, length must be less than or equal to `255`")  # noqa: E501

        self._user_id_key = user_id_key

    @property
    def auto_create_status(self):
        """Gets the auto_create_status of this OIDCUpstreamIdentityProvider.  # noqa: E501


        :return: The auto_create_status of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :rtype: AutoCreateStatus
        """
        return self._auto_create_status

    @auto_create_status.setter
    def auto_create_status(self, auto_create_status):
        """Sets the auto_create_status of this OIDCUpstreamIdentityProvider.


        :param auto_create_status: The auto_create_status of this OIDCUpstreamIdentityProvider.  # noqa: E501
        :type: AutoCreateStatus
        """

        self._auto_create_status = auto_create_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OIDCUpstreamIdentityProvider):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OIDCUpstreamIdentityProvider):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class OrganisationStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'all_up': 'bool',
        'admin_up': 'bool',
        'issuer_up': 'bool',
        'current_state': 'OrganisationStateStatus'
    }

    attribute_map = {
        'all_up': 'all_up',
        'admin_up': 'admin_up',
        'issuer_up': 'issuer_up',
        'current_state': 'current_state'
    }

    def __init__(self, all_up=None, admin_up=None, issuer_up=None, current_state=None, local_vars_configuration=None):  # noqa: E501
        """OrganisationStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._all_up = None
        self._admin_up = None
        self._issuer_up = None
        self._current_state = None
        self.discriminator = None

        self.all_up = all_up
        self.admin_up = admin_up
        self.issuer_up = issuer_up
        if current_state is not None:
            self.current_state = current_state

    @property
    def all_up(self):
        """Gets the all_up of this OrganisationStatus.  # noqa: E501

        An aggregate status indicating that the organisation is fully ready.  # noqa: E501

        :return: The all_up of this OrganisationStatus.  # noqa: E501
        :rtype: bool
        """
        return self._all_up

    @all_up.setter
    def all_up(self, all_up):
        """Sets the all_up of this OrganisationStatus.

        An aggregate status indicating that the organisation is fully ready.  # noqa: E501

        :param all_up: The all_up of this OrganisationStatus.  # noqa: E501
        :type: bool
        """

        self._all_up = all_up

    @property
    def admin_up(self):
        """Gets the admin_up of this OrganisationStatus.  # noqa: E501

        status of organisation admin portal  # noqa: E501

        :return: The admin_up of this OrganisationStatus.  # noqa: E501
        :rtype: bool
        """
        return self._admin_up

    @admin_up.setter
    def admin_up(self, admin_up):
        """Sets the admin_up of this OrganisationStatus.

        status of organisation admin portal  # noqa: E501

        :param admin_up: The admin_up of this OrganisationStatus.  # noqa: E501
        :type: bool
        """

        self._admin_up = admin_up

    @property
    def issuer_up(self):
        """Gets the issuer_up of this OrganisationStatus.  # noqa: E501

        status of organisation issuer  # noqa: E501

        :return: The issuer_up of this OrganisationStatus.  # noqa: E501
        :rtype: bool
        """
        return self._issuer_up

    @issuer_up.setter
    def issuer_up(self, issuer_up):
        """Sets the issuer_up of this OrganisationStatus.

        status of organisation issuer  # noqa: E501

        :param issuer_up: The issuer_up of this OrganisationStatus.  # noqa: E501
        :type: bool
        """

        self._issuer_up = issuer_up

    @property
    def current_state(self):
        """Gets the current_state of this OrganisationStatus.  # noqa: E501


        :return: The current_state of this OrganisationStatus.  # noqa: E501
        :rtype: OrganisationStateStatus
        """
        return self._current_state

    @current_state.setter
    def current_state(self, current_state):
        """Sets the current_state of this OrganisationStatus.


        :param current_state: The current_state of this OrganisationStatus.  # noqa: E501
        :type: OrganisationStateStatus
        """

        self._current_state = current_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganisationStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganisationStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_system_stats import AgentConnectorSystemStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorSystemStats(unittest.TestCase):
    """AgentConnectorSystemStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorSystemStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_system_stats.AgentConnectorSystemStats()  # noqa: E501
        if include_optional :
            return AgentConnectorSystemStats(
                os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux', 
                os_uptime = 45232, 
                agent_uptime = 45000, 
                agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259', 
                agent_release_train = 'stable', 
                agent_connector_id = 'SdaAs93adflq3a', 
                agent_connector_org_id = 'd0d4laSDr4ws9'
            )
        else :
            return AgentConnectorSystemStats(
                os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux',
                os_uptime = 45232,
                agent_uptime = 45000,
                agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259',
                agent_connector_id = 'SdaAs93adflq3a',
                agent_connector_org_id = 'd0d4laSDr4ws9',
        )

    def testAgentConnectorSystemStats(self):
        """Test AgentConnectorSystemStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
